"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setCachedResponse = exports.getCachedResponse = exports.initCachedResponse = void 0;
const store_1 = __importDefault(require("./store"));
const LRU = require("lru-cache");
let cache = undefined;
function initCachedResponse(cacheOptions) {
    cache = new LRU(Object.assign({ ttl: 1000 * 60 * 10, max: 200 }, cacheOptions));
}
exports.initCachedResponse = initCachedResponse;
function getCachedResponse({ req, ctx }) {
    const config = store_1.default.get("config");
    const cacheOptions = config.cache;
    try {
        const key = composeKey(req, ctx);
        return cache.get(key);
    }
    catch (e) {
        if (e === "not set") {
            console.error(`Using cache=true but cacheOptions is not configured.`);
        }
        else {
            console.error(`Could not retrieve cache using ctx[${cacheOptions.ctxKey}]`);
        }
    }
    return undefined;
}
exports.getCachedResponse = getCachedResponse;
function setCachedResponse({ req, ctx, responseData, }) {
    const config = store_1.default.get("config");
    const cacheOptions = config.cache;
    try {
        const key = composeKey(req, ctx);
        cache.set(key, responseData);
    }
    catch (e) {
        if (e === "not set") {
            console.error(`Using cache=true but cacheOptions is not configured.`);
        }
        else {
            console.error(`Could not retrieve cache using ctx[${cacheOptions.ctxKey}]`);
        }
    }
}
exports.setCachedResponse = setCachedResponse;
function composeKey(req, ctx) {
    const config = store_1.default.get("config");
    const cacheOptions = config.cache;
    if (!cacheOptions) {
        throw "not set";
    }
    const ctxKey = ctx[cacheOptions.ctxKey];
    if (!ctxKey) {
        throw "";
    }
    const httpMethod = req.method;
    const routePath = req.path;
    const key = `${httpMethod}-${ctx[cacheOptions.ctxKey]}-${routePath}`;
    return key;
}
